var conf = require('./config/development.json');

function options(path) {
    var opt = conf.bristolapi.options;
    opt.path = path;
    return opt;
}

// export variables and functions for testing
exports.options = options;

var https = require('https');

// rate limiter to avoid "API calls quota exceeded! maximum admitted 5 per Second."
var RateLimiter = require('limiter').RateLimiter;
var limiter = new RateLimiter(conf.bristolapi.rate, 'second');

function invoke(path) {
    // Return a new promise.
    return new Promise(function(resolve, reject) {

        var callback = function(response) {
            // streamed response
            var body = '';
            response.on('data', function(d) { body += d; });
            response.on('end', function() { 
                var json = JSON.parse(body);
                //console.log(JSON.stringify(json,null,4));
                resolve(json);
            });
        };
        try { 
            limiter.removeTokens(1, function(err, remainingRequests) {
                https.get(options(path),callback);
            });
        }
        catch (err) { reject(err.message); }
    });
}


exports.invoke = invoke;